@@ -595,7 +595,7 @@ void EditEuTransaction::slotAccountChanged(int i){
       const AB_EUTRANSFER_INFO_LIST *eil=0;
 
       j=AB_JobEuTransfer_new(ba);
-      if (AB_Job_CheckAvailability(j, 0)==0) {
+      if (AB_Job_CheckAvailability(j)==0) {
         /* get job parameters */
         eil=AB_JobEuTransfer_GetCountryInfoList(j);
         _ibanAllowed=AB_JobEuTransfer_GetIbanAllowed(j);
@@ -721,7 +721,7 @@ bool EditEuTransaction::_selectCountry(const QString &qs, bool byLong,
       const AB_EUTRANSFER_INFO *ei=0;
 
       j=AB_JobEuTransfer_new(ba);
-      if (AB_Job_CheckAvailability(j, 0)==0) {
+      if (AB_Job_CheckAvailability(j)==0) {
         std::string name;
 
         name=KBanking::QStringToUtf8String(qs);
