@@ -506,7 +506,7 @@ void EditStandingOrder::accept(){
 
       if (_isCreateMode) {
 	j=AB_JobCreateStandingOrder_new(ba);
-	if (AB_Job_CheckAvailability(j, 0)==0) {
+	if (AB_Job_CheckAvailability(j)==0) {
 	  standingOrderGroup->setEnabled(true);
 	  lim=AB_JobCreateStandingOrder_GetFieldLimits(j);
 	}
@@ -527,7 +527,7 @@ void EditStandingOrder::accept(){
       }
       else {
 	j=AB_JobModifyStandingOrder_new(ba);
-	if (AB_Job_CheckAvailability(j, 0)==0) {
+	if (AB_Job_CheckAvailability(j)==0) {
 	  standingOrderGroup->setEnabled(true);
 	  lim=AB_JobModifyStandingOrder_GetFieldLimits(j);
 	}
@@ -886,7 +886,7 @@ void EditStandingOrder::slotAccountChanged(int i){
 
       if (_isCreateMode) {
 	j=AB_JobCreateStandingOrder_new(ba);
-	if (AB_Job_CheckAvailability(j, 0)==0) {
+	if (AB_Job_CheckAvailability(j)==0) {
 	  standingOrderGroup->setEnabled(true);
 	  lim=AB_JobCreateStandingOrder_GetFieldLimits(j);
 	}
@@ -905,7 +905,7 @@ void EditStandingOrder::slotAccountChanged(int i){
       }
       else {
 	j=AB_JobModifyStandingOrder_new(ba);
-	if (AB_Job_CheckAvailability(j, 0)==0) {
+	if (AB_Job_CheckAvailability(j)==0) {
 	  standingOrderGroup->setEnabled(true);
 	  lim=AB_JobModifyStandingOrder_GetFieldLimits(j);
 	}
