@@ -705,7 +705,7 @@ void EditTransaction::slotAccountChanged(int i){
       if (_isDated) {
         if (_isCreate) {
           j=AB_JobCreateDatedTransfer_new(ba);
-	  if (AB_Job_CheckAvailability(j, 0)==0) {
+	  if (AB_Job_CheckAvailability(j)==0) {
             lim=AB_JobCreateDatedTransfer_GetFieldLimits(j);
           }
           else {
@@ -723,7 +723,7 @@ void EditTransaction::slotAccountChanged(int i){
         }
         else {
           j=AB_JobModifyDatedTransfer_new(ba);
-	  if (AB_Job_CheckAvailability(j, 0)==0) {
+	  if (AB_Job_CheckAvailability(j)==0) {
             lim=AB_JobModifyDatedTransfer_GetFieldLimits(j);
           }
           else {
@@ -743,7 +743,7 @@ void EditTransaction::slotAccountChanged(int i){
       else {
         if (_transfer.ref().getTransferType()==Transfer::TransferType_DebitNote) {
           j=AB_JobSingleDebitNote_new(ba);
-	  if (AB_Job_CheckAvailability(j, 0)==0) {
+	  if (AB_Job_CheckAvailability(j)==0) {
             lim=AB_JobSingleDebitNote_GetFieldLimits(j);
           }
           else {
@@ -761,7 +761,7 @@ void EditTransaction::slotAccountChanged(int i){
         }
         else {
           j=AB_JobSingleTransfer_new(ba);
-	  if (AB_Job_CheckAvailability(j, 0)==0) {
+	  if (AB_Job_CheckAvailability(j)==0) {
             lim=AB_JobSingleTransfer_GetFieldLimits(j);
           }
           else {
