@@ -169,9 +169,7 @@ bool TransactionFinder::init(){
   int i, j, idx;
   int rv;
 
-  rv=_app->loadAppSubConfig("gui/dlgs/transactionFinder",
-			    &dbConfig,
-			    0);
+  rv=_app->loadAppSubConfig("gui/dlgs/transactionFinder", &dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
   }
@@ -472,9 +470,7 @@ bool TransactionFinder::fini(){
     ++it;
   }
 
-  rv=_app->saveAppSubConfig("gui/dlgs/transactionFinder",
-			    dbConfig,
-			    0);
+  rv=_app->saveAppSubConfig("gui/dlgs/transactionFinder", dbConfig);
   GWEN_DB_Group_free(dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
