@@ -96,7 +96,7 @@ int KBanking::executeQueue(AB_IMEXPORTER_CONTEXT *ctx){
   int rv;
   AB_JOB_LIST2_ITERATOR *jit;
 
-  rv=QBanking::executeJobs(_jobQueue, ctx, 0);
+  rv=QBanking::executeJobs(_jobQueue, ctx);
   jit=AB_Job_List2_First(_jobQueue);
   if (jit) {
     AB_JOB *j;
@@ -319,9 +319,7 @@ int KBanking::init(){
     w.gatherInfoFromPurpose();
   }
 
-  rv=loadAppSubConfig("kbanking/app",
-		      &dbConfig,
-		      0);
+  rv=loadAppSubConfig("kbanking/app", &dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
   }
@@ -353,9 +351,7 @@ int KBanking::fini(){
 		      "useColoursForCategoryText",
 		      _useColoursForCategoryText?1:0);
 
-  rv=saveAppSubConfig("kbanking/app",
-		      dbConfig,
-		      0);
+  rv=saveAppSubConfig("kbanking/app", dbConfig);
   GWEN_DB_Group_free(dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
@@ -434,9 +430,7 @@ GWEN_DB_NODE *KBanking::getReportProfiles(Report *r) {
   path+="/profiles";
   GWEN_Buffer_free(nbuf);
 
-  rv=loadAppSubConfig(path.c_str(),
-		      &dbConfig,
-		      0);
+  rv=loadAppSubConfig(path.c_str(), &dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
     return NULL;
@@ -498,9 +492,7 @@ int KBanking::addReportProfile(Report *r, GWEN_DB_NODE *dbProfile){
   path+="/profiles";
   GWEN_Buffer_free(nbuf);
 
-  rv=loadAppSubConfig(path.c_str(),
-		      &dbConfig,
-		      0);
+  rv=loadAppSubConfig(path.c_str(), &dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
     return rv;
@@ -516,9 +508,7 @@ int KBanking::addReportProfile(Report *r, GWEN_DB_NODE *dbProfile){
     GWEN_DB_SetCharValue(dbNew, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			 "id", numbuf);
 
-    rv=saveAppSubConfig(path.c_str(),
-			dbConfig,
-			0);
+    rv=saveAppSubConfig(path.c_str(), dbConfig);
     GWEN_DB_Group_free(dbConfig);
     if (rv<0) {
       DBG_INFO(0, "here (%d)", rv);
@@ -727,7 +717,7 @@ int KBanking::_newTransferJob(Transfer::TransferType tt,
       return GWEN_ERROR_INVALID;
     }
 
-    rv=AB_Job_CheckAvailability(job, 0);
+    rv=AB_Job_CheckAvailability(job);
     if (rv) {
       DBG_NOTICE(0, "Job is not available (%d)", rv);
       AB_Job_free(job);
@@ -1140,7 +1130,7 @@ int KBanking::_newStandingOrderJob(RefPointer<Transaction> tmpl,
     // create job
     job=AB_JobCreateStandingOrder_new(ba);
 
-    rv=AB_Job_CheckAvailability(job, 0);
+    rv=AB_Job_CheckAvailability(job);
     if (rv) {
       DBG_NOTICE(0, "Job is not available (%d)", rv);
       AB_Job_free(job);
@@ -1363,7 +1353,7 @@ int KBanking::_newDatedTransferJob(RefPointer<Transaction> tmpl,
 
     // create job
     job=AB_JobCreateDatedTransfer_new(ba);
-    rv=AB_Job_CheckAvailability(job, 0);
+    rv=AB_Job_CheckAvailability(job);
     if (rv) {
       DBG_NOTICE(0, "Job is not available (%d)", rv);
       QMessageBox::critical(parent,
