@@ -50,7 +50,9 @@
 
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/version.h>
+
 #include <aqbanking/version.h>
+#include <aqbanking/dlg_importer.h>
 
 #include <unistd.h>
 #ifdef OS_WIN32
@@ -172,9 +174,7 @@ bool MainWindow::init() {
   GWEN_DB_NODE *dbConfig=NULL;
   int rv;
 
-  rv=_app->loadAppSubConfig("gui/windows/mainWindow",
-			    &dbConfig,
-			    0);
+  rv=_app->loadAppSubConfig("gui/windows/mainWindow", &dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
   }
@@ -221,9 +221,7 @@ bool MainWindow::fini() {
   GWEN_DB_SetIntValue(dbConfig, GWEN_DB_FLAGS_OVERWRITE_VARS,
 		      "height", height());
 
-  rv=_app->saveAppSubConfig("gui/windows/mainWindow",
-			    dbConfig,
-			    0);
+  rv=_app->saveAppSubConfig("gui/windows/mainWindow", dbConfig);
   GWEN_DB_Group_free(dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
@@ -400,7 +398,7 @@ void MainWindow::slotAbout(){
 			   tr("<qt>"
 			      "<p>"
 			      "This is QBankManager v%1<br>"
-			      "(c) 2004, 2005, 2006 Martin Preuss"
+			      "(c) 2004-2010 Martin Preuss"
 			      "</p>"
 			      "<p>"
 			      "QBankManager is based on <b>AqBanking</b>, "
@@ -441,19 +439,79 @@ void MainWindow::slotAbout(){
 
 
 void MainWindow::slotImport(){
+  GWEN_DIALOG *dlg;
+  AB_IMEXPORTER_CONTEXT *ctx;
+  int rv;
+  std::string str;
+
+  ctx=AB_ImExporterContext_new();
+  str=std::string(tr("Your file has been successfully imported.\n"
+		     "Click the finish button below to import the "
+		     "data into the application\n").utf8());
+  dlg=AB_ImporterDialog_new(_app->getCInterface(), ctx,
+                            str.c_str());
+
+  if (dlg==NULL) {
+    fprintf(stderr, "Could not create dialog\n");
+    return;
+  }
+
+  rv=GWEN_Gui_ExecDialog(dlg, 0);
+  fprintf(stderr, "Result: %d\n", rv);
+  if (rv==0) {
+    fprintf(stderr, "Rejected.\n");
+    return;
+  }
+
   _app->nextSession();
-  QBImporter::import(_app,
-		     QBANKING_IMPORTER_FLAGS_ASK_ALL_DUPES |
-		     QBANKING_IMPORTER_FLAGS_FUZZY,
-                     this);
+  if (!_app->importContext(ctx,
+			   QBANKING_IMPORTER_FLAGS_ASK_ALL_DUPES |
+			   QBANKING_IMPORTER_FLAGS_FUZZY)) {
+    fprintf(stderr, "Error importing data from file\n");
+  }
+  AB_ImExporterContext_free(ctx);
 }
 
 
 
 void MainWindow::slotImportAsOrders(){
-  QBImporter::import(_app,
-		     QBANKING_IMPORTER_FLAGS_AS_ORDERS,
-		     this);
+  GWEN_DIALOG *dlg;
+  AB_IMEXPORTER_CONTEXT *ctx;
+  int rv;
+  std::string str1;
+  std::string str2;
+
+  ctx=AB_ImExporterContext_new();
+  str1=std::string(tr("Your file has been successfully imported.\n"
+		      "Click the finish button below to import the "
+		      "data into the application\n").utf8());
+  dlg=AB_ImporterDialog_new(_app->getCInterface(), ctx,
+			    str1.c_str());
+
+  if (dlg==NULL) {
+    fprintf(stderr, "Could not create dialog\n");
+    AB_ImExporterContext_free(ctx);
+    return;
+  }
+
+  str2=std::string(tr("Import Transfers").utf8());
+  GWEN_Dialog_SetWidgetText(dlg, "", str2.c_str());
+
+  rv=GWEN_Gui_ExecDialog(dlg, 0);
+  fprintf(stderr, "Result: %d\n", rv);
+  if (rv==0) {
+    fprintf(stderr, "Rejected.\n");
+    GWEN_Dialog_free(dlg);
+    AB_ImExporterContext_free(ctx);
+    return;
+  }
+  GWEN_Dialog_free(dlg);
+
+  _app->nextSession();
+  if (!_app->importContext(ctx, QBANKING_IMPORTER_FLAGS_AS_ORDERS)) {
+    fprintf(stderr, "Error importing data from file\n");
+  }
+  AB_ImExporterContext_free(ctx);
 }
 
 
@@ -639,16 +697,21 @@ void MainWindow::slotSettings() {
 
 
 void MainWindow::slotCurrentDebug() {
-  AB_BANKINFO *bi=0;
+  AB_IMEXPORTER_CONTEXT *ctx;
+  GWEN_DIALOG *dlg;
+  int rv;
 
-  bi=_app->selectBank(0, "Test: Get Bank");
-  if (bi) {
-    DBG_ERROR(0, "Bi: %p", bi);
-    AB_BankInfo_free(bi);
-  }
-  else {
-    DBG_ERROR(0, "No bi");
+  ctx=AB_ImExporterContext_new();
+  dlg=AB_ImporterDialog_new(_app->getCInterface(),
+			    ctx, "File import test successfully finished.");
+  if (dlg==NULL) {
+    fprintf(stderr, "Could not create dialog\n");
+    return;
   }
+
+  rv=GWEN_Gui_ExecDialog(dlg, 0);
+  fprintf(stderr, "Result: %d\n", rv);
+
 }
 
 
