@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: account.cpp 435 2008-02-11 13:42:42Z martin $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -82,6 +82,12 @@ void Account::updateFromBankingAccount(const AB_ACCOUNT *a) {
   p=AB_Account_GetOwnerName(a);
   if (p)
     _ownerName=p;
+  p=AB_Account_GetIBAN(a);
+  if (p)
+    _iban=p;
+  p=AB_Account_GetBIC(a);
+  if (p)
+    _bic=p;
 }
 
 
@@ -103,6 +109,8 @@ Account::Account(const Account &a)
   _ownerName=a._ownerName;
   _transactions=a._transactions;
   _bankingId=a._bankingId;
+  _iban=a._iban;
+  _bic=a._bic;
   _banking=a._banking;
   _lastTransactionDate=a._lastTransactionDate;
   if (a._accountStatus)
@@ -136,6 +144,8 @@ bool Account::fromDb(GWEN_DB_NODE *db) {
   _bankName=GWEN_DB_GetCharValue(db, "bankName", 0, "");
   _accountName=GWEN_DB_GetCharValue(db, "accountName", 0, "");
   _ownerName=GWEN_DB_GetCharValue(db, "ownerName", 0, "");
+  _iban=GWEN_DB_GetCharValue(db, "iban", 0, "");
+  _bic=GWEN_DB_GetCharValue(db, "bic", 0, "");
 
   dbT=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST, "accountStatus");
   if (dbT)
@@ -242,6 +252,12 @@ bool Account::toDb(GWEN_DB_NODE *db) {
   if (!_ownerName.empty())
     GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                          "ownerName", _ownerName.c_str());
+  if (!_iban.empty())
+    GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			 "iban", _iban.c_str());
+  if (!_bic.empty())
+    GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			 "bic", _bic.c_str());
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                       "bankingId", _bankingId);
 
@@ -1125,6 +1141,33 @@ void Account::setOptionExcludeFromGlobalCall(bool b) {
 
 
 
+const std::string &Account::getIban() const {
+  return _iban;
+}
+
+
+
+void Account::setIban(const std::string &s) {
+  _iban=s;
+}
+
+
+
+const std::string &Account::getBic() const {
+  return _bic;
+}
+
+
+
+void Account::setBic(const std::string &s) {
+  _bic=s;
+}
+
+
+
+
+
+
 
 
 
