@@ -21,8 +21,6 @@
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/directory.h>
 #include <gwenhywfar/text.h>
-#include <gwenhywfar/io_file.h>
-#include <gwenhywfar/iomanager.h>
 
 #include <stdlib.h>
 #include <sys/types.h>
@@ -95,14 +93,14 @@ int App::init() {
     return rv;
   }
 
-  rv=AB_Banking_OnlineInit(getCInterface(), 0);
+  rv=AB_Banking_OnlineInit(getCInterface());
   if (rv) {
     DBG_ERROR(0, "here (%d)", rv);
     return rv;
   }
 
   /* read configuration */
-  rv=loadAppSubConfig("prg", &dbConfig, 0);
+  rv=loadAppSubConfig("prg", &dbConfig);
   if (rv<0) {
     DBG_ERROR(0, "here (%d)", rv);
     return rv;
@@ -424,7 +422,7 @@ int App::fini() {
     delete *cit;
   _categories.clear();
 
-  rv=saveAppSubConfig("prg", dbConfig, 0);
+  rv=saveAppSubConfig("prg", dbConfig);
   if (rv<0) {
     DBG_INFO(0, "Error saving application data");
     GWEN_DB_Group_free(dbConfig);
@@ -433,7 +431,7 @@ int App::fini() {
   GWEN_DB_Group_free(dbConfig);
 
   /* finalize online banking stuff */
-  rv=AB_Banking_OnlineFini(getCInterface(), 0);
+  rv=AB_Banking_OnlineFini(getCInterface());
   if (rv)
     return rv;
 
@@ -579,7 +577,7 @@ int App::savePayees() {
   }
 
   rv=GWEN_DB_WriteFile(db, GWEN_Buffer_GetStart(bdir),
-		       GWEN_DB_FLAGS_DEFAULT, 0, 2000);
+		       GWEN_DB_FLAGS_DEFAULT);
   if (rv) {
     DBG_ERROR(0, "Could not write file \"%s\" (%d)",
 	      GWEN_Buffer_GetStart(bdir), rv);
@@ -622,8 +620,7 @@ int App::loadPayees() {
 
   rv=GWEN_DB_ReadFile(db, GWEN_Buffer_GetStart(bdir),
 		      GWEN_DB_FLAGS_DEFAULT |
-		      GWEN_PATH_FLAGS_CREATE_GROUP,
-		      0, 2000);
+		      GWEN_PATH_FLAGS_CREATE_GROUP);
   if (rv) {
     DBG_INFO(0, "Error reading payee file (%d)", rv);
     GWEN_Buffer_free(bdir);
@@ -711,8 +708,7 @@ int App::saveCategories() {
   }
 
   rv=GWEN_DB_WriteFile(db, GWEN_Buffer_GetStart(bdir),
-		       GWEN_DB_FLAGS_DEFAULT,
-		       0, 2000);
+		       GWEN_DB_FLAGS_DEFAULT);
   if (rv) {
     DBG_ERROR(0, "Could not write file \"%s\" (%d)",
 	      GWEN_Buffer_GetStart(bdir), rv);
@@ -744,9 +740,7 @@ int App::_loadCategoryFile(const char *fname) {
   db=GWEN_DB_Group_new("root");
   rv=GWEN_DB_ReadFile(db, fname,
 		      GWEN_DB_FLAGS_DEFAULT |
-		      GWEN_PATH_FLAGS_CREATE_GROUP,
-                      0,
-		      2000);
+		      GWEN_PATH_FLAGS_CREATE_GROUP);
   if (rv) {
     DBG_INFO(0, "Error reading category file (%d)", rv);
     return GWEN_ERROR_GENERIC;
@@ -1810,12 +1804,12 @@ bool App::getMatchingTransactions(GWEN_DB_NODE *dbRule,
 
         tbuf=GWEN_Buffer_new(0, 256, 0, 1);
         if (fromTime) {
-          GWEN_Time_toString(fromTime, "YYYY/MM/DD", tbuf);
+          GWEN_Time_toString(fromTime, "YYYY-MM-DD", tbuf);
           DBG_DEBUG(0, "FromTime: %s", GWEN_Buffer_GetStart(tbuf));
           GWEN_Buffer_Reset(tbuf);
         }
         if (toTime) {
-          GWEN_Time_toString(toTime, "YYYY/MM/DD", tbuf);
+          GWEN_Time_toString(toTime, "YYYY-MM-DD", tbuf);
           DBG_DEBUG(0, "ToTime: %s", GWEN_Buffer_GetStart(tbuf));
           GWEN_Buffer_Reset(tbuf);
         }
@@ -1832,7 +1826,7 @@ bool App::getMatchingTransactions(GWEN_DB_NODE *dbRule,
       }
 
       // copy matching transactions to final list
-      DBG_DEBUG(0, "Copying transactions (%d)", tmptl.size());
+      DBG_DEBUG(0, "Copying transactions (%d)", int(tmptl.size()));
       for (tit=tmptl.begin(); tit!=tmptl.end(); tit++) {
         DBG_DEBUG(0, "Checking transactions");
         if (_ruleAppliesToTransaction(dbRule, (*tit).ptr(), true)) {
@@ -1854,13 +1848,11 @@ int App::exportTransactions(GWEN_DB_NODE *dbRule,
                             const std::list<RefPointer<Transaction> > &tl){
   AB_IMEXPORTER_CONTEXT *ctx;
   std::list<RefPointer<Transaction> >::const_iterator it;
-  AB_IMEXPORTER *exporter;
   const char *exporterName;
+  AB_IMEXPORTER *exporter;
   GWEN_DB_NODE *dbProfile;
   int rv;
-  GWEN_IO_LAYER *io;
   const char *fname;
-  int fd;
 
   /* get exporter name */
   exporterName=GWEN_DB_GetCharValue(dbRule, "exporterText", 0, 0);
@@ -1891,70 +1883,47 @@ int App::exportTransactions(GWEN_DB_NODE *dbRule,
     return GWEN_ERROR_INVALID;
   }
 
-  /* open file */
-  fd=open(fname,
-          O_RDWR | O_TRUNC | O_CREAT,
-#ifdef WIN32
-		  0
-#else
-		  S_IRUSR | S_IWUSR
-#endif
-		  );
-  if (fd==-1) {
-    DBG_ERROR(0, "open(%s): %s", fname, strerror(errno));
-    return GWEN_ERROR_GENERIC;
-  }
-
-  io=GWEN_Io_LayerFile_new(0, fd);
-  GWEN_Io_Layer_AddFlags(io, GWEN_IO_LAYER_FLAGS_DONTCLOSE);
-  rv=GWEN_Io_Manager_RegisterLayer(io);
-  if (rv<0) {
-    DBG_ERROR(0, "Error registering layer (%d)", rv);
-    close(fd);
-    return rv;
-  }
-
   /* add transactions to context */
   ctx=AB_ImExporterContext_new();
   for (it=tl.begin(); it!=tl.end(); it++) {
     AB_TRANSACTION *bt;
+    std::string catId;
 
     bt=(*it).ref().toBankingTransaction();
     assert(bt);
+    catId=(*it).ref().getCategory();
+    if (!catId.empty()) {
+      Category *cat;
+
+      cat=findCategoryById(catId.c_str());
+      if (cat) {
+	std::string catPath;
+
+	catPath=cat->getPath();
+	if (cat->isIncome())
+	  catPath="income:"+catPath;
+        else
+	  catPath="expense:"+catPath;
+        AB_Transaction_ClearCategory(bt);
+        AB_Transaction_AddCategory(bt, catPath.c_str(), 0);
+      }
+    }
     AB_ImExporterContext_AddTransaction(ctx, bt);
   } /* for */
 
   AB_Banking_FillGapsInImExporterContext(getCInterface(), ctx);
 
   /* let exporter work */
-  rv=AB_ImExporter_Export(exporter,
-			  ctx,
-			  io,
-			  dbProfile,
-			  0);
+  rv=AB_ImExporter_ExportToFile(exporter,
+				ctx,
+                                fname,
+				dbProfile);
   AB_ImExporterContext_free(ctx);
   if (rv<0) {
     DBG_ERROR(0, "Export plugin signalled an error (%d)", rv);
-    GWEN_Io_Layer_free(io);
-    close(fd);
     return rv;
   }
-  else {
-    /* flush */
-    rv=GWEN_Io_Layer_DisconnectRecursively(io, NULL, 0, 0, 2000);
-    if (rv<0) {
-      DBG_ERROR(0, "Error on disconnect (%d)", rv);
-      GWEN_Io_Layer_free(io);
-      close(fd);
-      return rv;
-    }
-    GWEN_Io_Layer_free(io);
 
-    if (close(fd)) {
-      DBG_ERROR(0, "close(): %s", strerror(errno));
-      return GWEN_ERROR_IO;
-    }
-  }
   return 0;
 }
 
@@ -1968,9 +1937,7 @@ int App::exportTransfers(GWEN_DB_NODE *dbRule,
   const char *exporterName;
   GWEN_DB_NODE *dbProfile;
   int rv;
-  GWEN_IO_LAYER *io;
   const char *fname;
-  int fd;
 
   /* get exporter name */
   exporterName=GWEN_DB_GetCharValue(dbRule, "exporterText", 0, 0);
@@ -2001,29 +1968,6 @@ int App::exportTransfers(GWEN_DB_NODE *dbRule,
     return GWEN_ERROR_INVALID;
   }
 
-  /* open file */
-  fd=open(fname,
-          O_RDWR | O_TRUNC | O_CREAT,
-#ifdef WIN32
-	  0
-#else
-	  S_IRUSR | S_IWUSR
-#endif
-	 );
-  if (fd==-1) {
-    DBG_ERROR(0, "open(%s): %s", fname, strerror(errno));
-    return GWEN_ERROR_GENERIC;
-  }
-
-  io=GWEN_Io_LayerFile_new(0, fd);
-  GWEN_Io_Layer_AddFlags(io, GWEN_IO_LAYER_FLAGS_DONTCLOSE);
-  rv=GWEN_Io_Manager_RegisterLayer(io);
-  if (rv<0) {
-    DBG_ERROR(0, "Error registering layer (%d)", rv);
-    close(fd);
-    return rv;
-  }
-
   /* add transactions to context */
   ctx=AB_ImExporterContext_new();
   for (it=tl.begin(); it!=tl.end(); it++) {
@@ -2037,34 +1981,15 @@ int App::exportTransfers(GWEN_DB_NODE *dbRule,
   AB_Banking_FillGapsInImExporterContext(getCInterface(), ctx);
 
   /* let exporter work */
-  rv=AB_ImExporter_Export(exporter,
-			  ctx,
-			  io,
-			  dbProfile,
-			  0);
+  rv=AB_ImExporter_ExportToFile(exporter,
+				ctx,
+				fname,
+				dbProfile);
   AB_ImExporterContext_free(ctx);
   if (rv<0) {
     DBG_ERROR(0, "Export plugin signalled an error (%d)", rv);
-    GWEN_Io_Layer_free(io);
-    close(fd);
     return rv;
   }
-  else {
-    /* flush */
-    rv=GWEN_Io_Layer_DisconnectRecursively(io, NULL, 0, 0, 2000);
-    if (rv<0) {
-      DBG_ERROR(0, "Error on disconnect (%d)", rv);
-      GWEN_Io_Layer_free(io);
-      close(fd);
-      return rv;
-    }
-    GWEN_Io_Layer_free(io);
-
-    if (close(fd)) {
-      DBG_ERROR(0, "close(): %s", strerror(errno));
-      return GWEN_ERROR_IO;
-    }
-  }
   return 0;
 }
 
@@ -2720,7 +2645,7 @@ int App__convertFromUtf8(const char *text,
   else {
     char *outbuf;
     char *pOutbuf;
-#if defined(OS_LINUX) | defined(OS_WIN32)
+#if defined(OS_LINUX) | defined(OS_WIN32) | defined(OS_KFREEBSD)
     char *pInbuf;
 #else
     /* For Mac OSX */
@@ -2753,8 +2678,8 @@ int App__convertFromUtf8(const char *text,
       GWEN_Buffer_AppendBytes(tbuf, outbuf, space-outLeft);
       if (done) {
         DBG_INFO(0, "Unrevertable: [%s] -> [%s] (%d)",
-                 text,
-                 GWEN_Buffer_GetStart(tbuf), done);
+		 text,
+                 GWEN_Buffer_GetStart(tbuf), int(done));
       }
       free(outbuf);
       DBG_DEBUG(AQBANKING_LOGDOMAIN, "Conversion done.");
