@@ -801,9 +801,11 @@ std::string Transaction::_makeHash() {
   }
   s+="#";
 
+#if 0
   snprintf(buffer, sizeof(buffer), "%i", _textKey);
   s+=buffer;
   s+="#";
+#endif
 
   if (_valutaDate) {
     snprintf(buffer, sizeof(buffer), "%u",
@@ -829,8 +831,10 @@ std::string Transaction::_makeHash() {
       s+=p;
   }
   s+="#";
+#if 0
   s+=_transactionKey;
   s+="#";
+#endif
   s+=_customerReference;
   s+="#";
   s+=_bankReference;
@@ -838,8 +842,10 @@ std::string Transaction::_makeHash() {
   snprintf(buffer, sizeof(buffer), "%d", _transactionCode);
   s+=buffer;
   s+="#";
+#if 0
   s+=_transactionText;
   s+="#";
+#endif
   s+=_primanota;
   s+="#";
   s+=_fiid;
@@ -977,7 +983,11 @@ bool Transaction::toDb(GWEN_DB_NODE *db) const {
   GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                        "custref", _customerReference.c_str());
   GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-                       "bankref", _bankReference.c_str());
+		       "bankref", _bankReference.c_str());
+  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+		      "transactionCode", _transactionCode);
+  GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+		       "transactionText", _transactionText.c_str());
   GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                        "primanota", _primanota.c_str());
   GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
@@ -1120,6 +1130,8 @@ bool Transaction::fromDb(GWEN_DB_NODE *db) {
   _transactionText=GWEN_DB_GetCharValue(db, "text", 0, "");
   _customerReference=GWEN_DB_GetCharValue(db, "custref", 0, "");
   _bankReference=GWEN_DB_GetCharValue(db, "bankref", 0, "");
+  _transactionCode=GWEN_DB_GetIntValue(db, "transactionCode", 0, 0);
+  _transactionText=GWEN_DB_GetCharValue(db, "transactionText", 0, "");
   _primanota=GWEN_DB_GetCharValue(db, "primanota", 0, "");
   _fiid=GWEN_DB_GetCharValue(db, "fiid", 0, "");
   _payee=GWEN_DB_GetCharValue(db, "payee", 0, "");
