@@ -45,6 +45,7 @@ Transfer::Transfer(const AB_TRANSACTION *t,
                    Transfer::TransferType ty)
 :Transaction(t)
 ,_jobId(0)
+,_groupId(AB_Transaction_GetGroupId(t))
 ,_status(StatusUnknown)
 ,_transferType(ty)
 ,_lastStatusChange(0)
@@ -56,6 +57,7 @@ Transfer::Transfer(const AB_TRANSACTION *t,
 Transfer::Transfer(const Transfer &t)
 :Transaction(t)
 ,_jobId(t._jobId)
+,_groupId(t._groupId)
 ,_status(t._status)
 ,_transferType(t._transferType)
 ,_lastStatusChange(t._lastStatusChange)
@@ -67,6 +69,7 @@ Transfer::Transfer(const Transfer &t)
 Transfer::Transfer(const Transaction &t, Transfer::TransferType ty)
 :Transaction(t)
 ,_jobId(0)
+,_groupId(0)
 ,_status(StatusUnknown)
 ,_transferType(ty)
 ,_lastStatusChange(0)
@@ -78,6 +81,7 @@ Transfer::Transfer(const Transaction &t, Transfer::TransferType ty)
 Transfer::Transfer(GWEN_DB_NODE *db)
 :Transaction()
 ,_jobId(0)
+,_groupId(0)
 ,_status(StatusUnknown)
 ,_transferType(TransferType_Unknown)
 ,_lastStatusChange(0)
@@ -137,6 +141,18 @@ void Transfer::setJobId(uint32_t id){
 
 
 
+uint32_t Transfer::getGroupId() const {
+  return _groupId;
+}
+
+
+
+void Transfer::setGroupId(uint32_t id) {
+  _groupId=id;
+}
+
+
+
 Transfer::TransferType Transfer::getTransferType() const{
   return _transferType;
 }
@@ -174,6 +190,8 @@ bool Transfer::toDb(GWEN_DB_NODE *db) const{
 
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                       "jobId", _jobId);
+  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "groupId", _groupId);
   switch(_status) {
   case StatusEnqueued:    s="enqueued"; break;
   case StatusPending:     s="pending"; break;
@@ -202,6 +220,7 @@ bool Transfer::fromDb(GWEN_DB_NODE *db){
   }
 
   _jobId=GWEN_DB_GetIntValue(db, "jobid", 0, 0);
+  _groupId=GWEN_DB_GetIntValue(db, "groupid", 0, 0);
   _transferType=typeFromString(GWEN_DB_GetCharValue(db, "transferType", 0,
                                                     "simple"));
 
@@ -291,6 +310,8 @@ AB_TRANSACTION *Transfer::toBankingTransaction() {
     }
   }
 
+  AB_Transaction_SetGroupId(t, _groupId);
+
   return t;
 }
 
