@@ -73,8 +73,12 @@ public:
   TransferType getTransferType() const;
   void setTransferType(TransferType t);
 
+  uint32_t getGroupId() const;
+  void setGroupId(uint32_t id);
+
 private:
   uint32_t _jobId;
+  uint32_t _groupId;
   Status _status;
   TransferType _transferType;
   GWEN_TIME *_lastStatusChange;
