@@ -273,8 +273,7 @@ AH_STORAGE_DAY *AH_Storage_GetDay(AH_STORAGE *st,
                              GWEN_PATH_FLAGS_NAMEMUSTEXIST)==0) {
     if (GWEN_DB_ReadFile(n, GWEN_Buffer_GetStart(pbuf),
                          GWEN_DB_FLAGS_DEFAULT |
-			 GWEN_PATH_FLAGS_CREATE_GROUP,
-			 0, 2000)){
+			 GWEN_PATH_FLAGS_CREATE_GROUP)){
       if (ro) {
         DBG_ERROR(0, "Could not load file \"%s\"", GWEN_Buffer_GetStart(pbuf));
         GWEN_DB_Group_free(n);
@@ -303,8 +302,7 @@ int AH_Storage_SaveDay(AH_STORAGE *st, AH_STORAGE_DAY *dy) {
   if (GWEN_DB_Groups_Count(AH_Storage_Day_GetTransactions(dy))) {
     if (GWEN_DB_WriteFile(AH_Storage_Day_GetTransactions(dy),
 			  AH_Storage_Day_GetFileName(dy),
-			  GWEN_DB_FLAGS_DEFAULT,
-			  0, 2000)) {
+			  GWEN_DB_FLAGS_DEFAULT)) {
       DBG_ERROR(0, "Could not save day \"%s\"",
                 AH_Storage_Day_GetFileName(dy));
       return -1;
