@@ -83,9 +83,7 @@ bool DatedTransferView::init(){
   int i, j;
 
   path="gui/views/datedTransferview";
-  rv=_app->loadAppSubConfig(path.c_str(),
-			    &dbConfig,
-			    0);
+  rv=_app->loadAppSubConfig(path.c_str(), &dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
   }
@@ -162,9 +160,7 @@ bool DatedTransferView::fini(){
                         "columns", j);
   } /* for */
 
-  rv=_app->saveAppSubConfig(path.c_str(),
-			    dbConfig,
-			    0);
+  rv=_app->saveAppSubConfig(path.c_str(), dbConfig);
   GWEN_DB_Group_free(dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
@@ -288,7 +284,7 @@ AB_JOB *DatedTransferView::_newDatedXferJob(AB_JOB_TYPE jt,
       return 0;
     }
 
-    rv=AB_Job_CheckAvailability(job, 0);
+    rv=AB_Job_CheckAvailability(job);
     if (rv) {
       DBG_NOTICE(0, "Job is not available (%d)", rv);
       QMessageBox::critical(this,
@@ -547,7 +543,7 @@ void DatedTransferView::slotDeleteDatedTransfer() {
   }
 
   job=AB_JobDeleteDatedTransfer_new(ba);
-  rv=AB_Job_CheckAvailability(job, 0);
+  rv=AB_Job_CheckAvailability(job);
   if (rv) {
     DBG_ERROR(0, "Job is not available (%d)", rv);
     QMessageBox::critical(this,
