@@ -83,9 +83,7 @@ bool StandingOrderView::init(){
   int i, j;
 
   path="gui/views/stoview";
-  rv=_app->loadAppSubConfig(path.c_str(),
-			    &dbConfig,
-			    0);
+  rv=_app->loadAppSubConfig(path.c_str(), &dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
   }
@@ -162,9 +160,7 @@ bool StandingOrderView::fini(){
                         "columns", j);
   } /* for */
 
-  rv=_app->saveAppSubConfig(path.c_str(),
-			    dbConfig,
-			    0);
+  rv=_app->saveAppSubConfig(path.c_str(), dbConfig);
   GWEN_DB_Group_free(dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
@@ -287,7 +283,7 @@ AB_JOB *StandingOrderView::_newStoJob(AB_JOB_TYPE jt,
       return 0;
     }
 
-    rv=AB_Job_CheckAvailability(job, 0);
+    rv=AB_Job_CheckAvailability(job);
     if (rv) {
       DBG_NOTICE(0, "Job is not available (%d)", rv);
       AB_Job_free(job);
@@ -547,7 +543,7 @@ void StandingOrderView::slotDeleteStandingOrder() {
   }
 
   job=AB_JobDeleteStandingOrder_new(ba);
-  rv=AB_Job_CheckAvailability(job, 0);
+  rv=AB_Job_CheckAvailability(job);
   if (rv) {
     DBG_ERROR(0, "Job is not available (%d)", rv);
     QMessageBox::critical(this,
