@@ -181,9 +181,7 @@ bool TransactionView::init(){
     path+="/generic";
   }
 
-  rv=_app->loadAppSubConfig(path.c_str(),
-			    &dbConfig,
-			    0);
+  rv=_app->loadAppSubConfig(path.c_str(), &dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
   }
@@ -285,9 +283,7 @@ bool TransactionView::fini(){
 			"columns", j);
   } /* for */
 
-  rv=_app->saveAppSubConfig(path.c_str(),
-			    dbConfig,
-			    0);
+  rv=_app->saveAppSubConfig(path.c_str(), dbConfig);
   GWEN_DB_Group_free(dbConfig);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
