@@ -111,7 +111,7 @@ void StandingOrderListViewItem::_populate() {
       QDate t;
 
       t=QDate(year, month+1, day);
-      tmp+=t.toString();
+      tmp+=t.toString(Qt::LocalDate);
     }
   }
   tmp+="</qt>";
@@ -185,7 +185,7 @@ void StandingOrderListViewItem::_populate() {
       QDate t;
 
       t=QDate(year, month+1, day);
-      tmp+=t.toString();
+      tmp+=t.toString(Qt::LocalDate);
     }
   }
   tmp+="</qt>";
