@@ -190,7 +190,7 @@ void TransactionListViewItem::_populate(bool isCurrent) {
       QDate t;
 
       t=QDate(year, month+1, day);
-      tmp+=t.toString();
+      tmp+=t.toString(Qt::LocalDate);
     }
   }
   tmp+="</qt>";
