@@ -135,7 +135,7 @@ void TransferListViewItem::_populate() {
       QDate t;
 
       t=QDate(year, month+1, day);
-      tmp+=t.toString();
+      tmp+=t.toString(Qt::LocalDate);
     }
   }
   tmp+="</qt>";
