@@ -107,7 +107,7 @@ void TransactionListView2Item::setupColumn(int col) {
         QDate t;
 
         t=QDate(year, month+1, day);
-        tmp+=t.toString();
+        tmp+=t.toString(Qt::LocalDate);
       }
     }
     tmp+="</qt>";
