@@ -460,8 +460,7 @@ int main(int argc, char **argv) {
   //removeUnneeded(dbAccounts);
   assignId(dbAccounts, &i);
   if (GWEN_DB_WriteFile(dbAccounts, "out.db",
-			GWEN_DB_FLAGS_DEFAULT,
-                        0, 20000)) {
+			GWEN_DB_FLAGS_DEFAULT)) {
     DBG_ERROR(0, "Could not write file.\n");
     return 4;
   }
